@@ -3,12 +3,12 @@
 # License: MIT
 # Date: 3 May 2020
 
+
 import logging
+import os.path
 import sys
 
-from pathlib import Path
-
-from rsl_comm_py.shearwater_serial import ShearWaterSerial
+from um7py.shearwater_serial import ShearWaterSerial
 
 
 if __name__ == '__main__':
@@ -17,14 +17,13 @@ if __name__ == '__main__':
         format='[%(asctime)s.%(msecs)03d]: %(message)s',
         datefmt='%H:%M:%S',
         handlers=[
-            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
+            logging.FileHandler(f'{os.path.basename(__file__)}.log', mode='w'),
             logging.StreamHandler(sys.stdout),
         ])
-    script_dir = Path(__file__).parent
-    # NOTE: specify path to YOUR device file below (see README how to create such file):
-    device_file = script_dir.parent / "rsl_A500CNHD.json"
+    script_dir = os.path.dirname(__file__)
+    device_file = os.path.join(script_dir, os.pardir, "um7py", "um7_A500CNHD.json")
     shearwater = ShearWaterSerial(device=device_file)
 
-    for packet in shearwater.recv_broadcast(num_packets=100):
+    for packet in shearwater.recv_broadcast(num_packets=1000):
         logging.warning(packet)
 
