@@ -5,11 +5,10 @@
 
 
 import logging
+import os.path
 import sys
 
-from pathlib import Path
-
-from rsl_comm_py.shearwater_serial import ShearWaterSerial
+from um7py.shearwater_serial import ShearWaterSerial
 
 
 if __name__ == '__main__':
@@ -18,11 +17,11 @@ if __name__ == '__main__':
         format='[%(asctime)s.%(msecs)03d]: %(message)s',
         datefmt='%H:%M:%S',
         handlers=[
-            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
+            logging.FileHandler(f'{os.path.basename(__file__)}.log', mode='w'),
             logging.StreamHandler(sys.stdout),
         ])
-    script_dir = Path(__file__).parent
-    device_file = script_dir.parent / "rsl_A500CNHD.json"
+    script_dir = os.path.dirname(__file__)
+    device_file = os.path.join(script_dir, os.pardir, "um7py", "um7_A500CNHD.json")
     shearwater = ShearWaterSerial(device=device_file)
 
     for packet in shearwater.recv_health_broadcast(num_packets=100):
