@@ -5,11 +5,10 @@
 
 
 import logging
+import os.path
 import sys
 
-from pathlib import Path
-
-from rsl_comm_py.shearwater_serial import ShearWaterSerial
+from um7py.shearwater_serial import ShearWaterSerial
 
 
 if __name__ == '__main__':
@@ -18,16 +17,16 @@ if __name__ == '__main__':
         format='[%(asctime)s.%(msecs)03d]: %(message)s',
         datefmt='%H:%M:%S',
         handlers=[
-            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
+            logging.FileHandler(f'{os.path.basename(__file__)}.log', mode='w'),
             logging.StreamHandler(sys.stdout),
         ])
-    script_dir = Path(__file__).parent
-    device_file = script_dir.parent / "rsl_A500CNHD.json"
+    script_dir = os.path.dirname(__file__)
+    device_file = os.path.join(script_dir, os.pardir, "um7py", "um7_A500CNHD.json")
     shearwater = ShearWaterSerial(device=device_file)
     creg_com_rates5, *_ = shearwater.creg_com_rates5
     print("creg_com_rates5: {}".format(creg_com_rates5))
     creg_com_settings, *_ = shearwater.creg_com_settings
-    print("shearwater creg_com_settings: {}".format(creg_com_settings))
+    print("um7 creg_com_settings: {}".format(creg_com_settings))
 
     print(f"setting new quat rate: 20 Hz")
     # look at the register description -->
@@ -37,3 +36,4 @@ if __name__ == '__main__':
     # we have now set a raw register value, let us write it in the sensor
     print(creg_com_rates5)
     shearwater.creg_com_rates5 = creg_com_rates5.raw_value
+
