@@ -4,11 +4,10 @@
 # Date: 3 May 2020
 
 import logging
+import os.path
 import sys
 
-from pathlib import Path
-
-from rsl_comm_py.shearwater_serial import ShearWaterSerial
+from um7py.shearwater_serial import ShearWaterSerial
 
 
 if __name__ == '__main__':
@@ -17,11 +16,11 @@ if __name__ == '__main__':
         format='[%(asctime)s.%(msecs)03d] [%(levelname)-8s]:  %(message)s',
         datefmt='%Y-%m-%d %H:%M:%S',
         handlers=[
-            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
+            logging.FileHandler(f'{os.path.basename(__file__)}.log'),
             logging.StreamHandler(sys.stdout),
         ])
-    script_dir = Path(__file__).parent
-    device_file = script_dir.parent / "rsl_A500CNHD.json"
+    script_dir = os.path.dirname(__file__)
+    device_file = os.path.join(script_dir, os.pardir, "um7py", "um7_A500CNHD.json")
     shearwater = ShearWaterSerial(device=device_file)
 
     print(f"\n========== COMMAND REGISTERS ===================================")
