@@ -4,11 +4,10 @@
 # Date: 31 March 2020
 
 import logging
+import os.path
 import sys
 
-from pathlib import Path
-
-from rsl_comm_py.shearwater_serial import ShearWaterSerial
+from um7py.shearwater_serial import ShearWaterSerial
 
 
 if __name__ == '__main__':
@@ -17,14 +16,15 @@ if __name__ == '__main__':
         format='[%(asctime)s.%(msecs)03d] [%(levelname)-8s]:  %(message)s',
         datefmt='%Y-%m-%d %H:%M:%S',
         handlers=[
-            logging.FileHandler(f'{Path(__file__).stem}.log'),
+            logging.FileHandler(f'{os.path.basename(__file__)}.log'),
             logging.StreamHandler(sys.stdout),
         ])
-    script_dir = Path(__file__).parent
-    device_file = script_dir.parent / "rsl_A500CNHD.json"
+    script_dir = os.path.dirname(__file__)
+    device_file = os.path.join(script_dir, os.pardir, "um7py", "um7_A500CNHD.json")
     shearwater = ShearWaterSerial(device=device_file)
 
     print(f"\n========== INCLINATION ===================================")
-    for _ in range(10):
+    for _ in range(10000):
         print(f"dreg_velocity_time            : {shearwater.dreg_velocity_time[1]}")
 
+
