@@ -8,7 +8,8 @@ import logging
 import os.path
 import sys
 
-from rsl_comm_py.um7_serial import UM7Serial
+from um7py.um7_serial import UM7Serial
+
 
 if __name__ == '__main__':
     logging.basicConfig(
@@ -20,9 +21,8 @@ if __name__ == '__main__':
             logging.StreamHandler(sys.stdout),
         ])
     script_dir = os.path.dirname(__file__)
-    device_file = os.path.join(script_dir, os.pardir, "um7_A500CNP8.json")
+    device_file = os.path.join(script_dir, os.pardir, "um7py", "um7_A500CNP8.json")
     um7 = UM7Serial(device=device_file)
 
-    flush_on_start = True  # <-- optional, set to true if you want to reset input buffer when starting reception
-    for packet in um7.recv_all_raw_broadcast(num_packets=10000, flush_buffer_on_start=flush_on_start):
+    for packet in um7.recv_all_raw_broadcast(num_packets=10000):
         logging.warning(packet)
